@@ -2,7 +2,7 @@
 
 """ The work time log app tracks working hours in an interaction model similar to git. """
 
-__version__: str = "0.99.1"
+__version__: str = "0.99.2.post1"
 
 import csv
 import datetime as dt
@@ -47,7 +47,7 @@ DATE_FORMAT_FULL = "%A, " + DATE_FORMAT
 
 
 class Work:
-    """ Main class """
+    """Main class"""
 
     def __init__(self):
         self.base_dir: pathlib.Path
@@ -56,7 +56,7 @@ class Work:
         self.configuration: RC
 
     def _reinit(self, base_dir: pathlib.Path) -> None:
-        """ Connect the DAO and load the RC """
+        """Connect the DAO and load the RC"""
 
         # Connect the DAOs
         self.dao = WorkDao(base_dir)
@@ -66,7 +66,7 @@ class Work:
         self.configuration = RC.load_rc()
 
     def main(self) -> None:
-        """ Main program flow. """
+        """Main program flow."""
 
         # Argument parsing
         parser = Arguments.create_argparser(version=__version__, program=self)
@@ -165,7 +165,7 @@ class Work:
     ### Argument parsing / Step two ###
 
     def get_single_time(self, args) -> dt.datetime:
-        """ Resolve the single time argument (start, stop). """
+        """Resolve the single time argument (start, stop)."""
 
         if args.mode not in [START_NAME, STOP_NAME]:
             raise ValueError("Expecting start or stop mode!")
@@ -198,7 +198,7 @@ class Work:
     def get_time_from_and_to(
         self, args, baseline_date: dt.date
     ) -> Tuple[dt.datetime, dt.datetime]:
-        """ Resolve the from and to time arguments. """
+        """Resolve the from and to time arguments."""
 
         if args.mode not in [ADD_NAME, *SWITCH_NAMES]:
             raise ValueError("Expecting add or switch mode!")
@@ -280,7 +280,7 @@ class Work:
     # start #
 
     def start(self, args) -> None:
-        """	Start the protocol based on the given arguments. """
+        """Start the protocol based on the given arguments."""
 
         start_time: dt.datetime = self.get_single_time(args)
         self._start(start_time=start_time, force=args.force, dry_run=args.dry_run)
@@ -332,7 +332,7 @@ class Work:
     # stop #
 
     def stop(self, args) -> None:
-        """ Stop the protocol based on the given arguments. """
+        """Stop the protocol based on the given arguments."""
         end_time: dt.datetime = self.get_single_time(args)
         run_length: float = self._stop(
             end_time=end_time,
@@ -376,7 +376,7 @@ class Work:
     # add #
 
     def add(self, args) -> None:
-        """ Add a protocol entry consisting of start time, end time and optional date flag. """
+        """Add a protocol entry consisting of start time, end time and optional date flag."""
 
         start_time: dt.datetime
         end_time: dt.datetime
@@ -543,7 +543,7 @@ class Work:
     # cancel #
 
     def cancel(self, args) -> None:
-        """ Cancels the current run. """
+        """Cancels the current run."""
 
         if not self.dao.run_active():
             print("No active run")
@@ -556,7 +556,7 @@ class Work:
     # resume #
 
     def resume(self, args) -> None:
-        """ Resumes the last run. """
+        """Resumes the last run."""
 
         if not args.force and self.dao.run_active():
             raise InvalidOperationWarning.cant(
@@ -582,7 +582,7 @@ class Work:
     # status #
 
     def status(self, args) -> None:
-        """ Print the current status. """
+        """Print the current status."""
 
         today: dt.date = dt.date.today()
         active_start: Optional[dt.datetime] = self.dao.get_start_time()
@@ -636,7 +636,6 @@ class Work:
 
         minutes_left_today: float = minutes_to_work - total_minutes_worked
         minutes_left_delta_str: str = self._timedelta_str(abs(minutes_left_today))
-        prospective_start: dt.datetime = self._prospective_start(active_start)
 
         output += new_section_line()
 
@@ -646,11 +645,13 @@ class Work:
                 done_msg += " (" + minutes_left_delta_str + " over)"
             output += Color.color(done_msg, Color.GREEN)
         else:
+            prospective_start: dt.datetime = self._prospective_start(active_start)
+            work_until: dt.datetime = prospective_start + dt.timedelta(
+                minutes=minutes_to_work - minutes_protocol
+            )
             output += "{} left (until {})".format(
                 minutes_left_delta_str,
-                (prospective_start + dt.timedelta(minutes=minutes_left_today)).strftime(
-                    TIME_FORMAT
-                ),
+                work_until.strftime(TIME_FORMAT),
             )
 
             output += new_section_line() + "Week balance: "
@@ -683,7 +684,7 @@ class Work:
     # hours #
 
     def hours(self, args):
-        """ Print the hours worked until a specified time or related things. """
+        """Print the hours worked until a specified time or related things."""
 
         today: dt.date = dt.date.today()
         minutes_logged, minutes_active_run = self._total_minutes_worked()
@@ -814,7 +815,7 @@ class Work:
 
     @dataclass
     class HoursData:
-        """ Storage container for data used in hours sub-functions. """
+        """Storage container for data used in hours sub-functions."""
 
         minutes_logged: float
         minutes_active_run: float
@@ -827,12 +828,12 @@ class Work:
 
         @property
         def total_minutes_worked(self) -> float:
-            """ Return the sum of the logged minutes and the active run minutes. """
+            """Return the sum of the logged minutes and the active run minutes."""
             return self.minutes_logged + self.minutes_active_run
 
     def _get_hours_worked_until_msg(self, target_time, hours_data):
         # type: (dt.datetime, Work.HoursData) -> str
-        """ Compute and stringify the worked hours at a given target time. """
+        """Compute and stringify the worked hours at a given target time."""
 
         minutes_from_now: float = (
             target_time - hours_data.worked_towork_split
@@ -854,7 +855,7 @@ class Work:
 
     def _get_target_end_time_msg(self, target_hours, target_minutes, hours_data):
         # type: (int, int, Work.HoursData) -> str
-        """ Compute and stringify the status towards a given time target. """
+        """Compute and stringify the status towards a given time target."""
 
         target_time: str = f"{target_hours}:{target_minutes:0>2}"
         target_minutes += target_hours * 60
@@ -962,7 +963,7 @@ class Work:
         return f"{message} ({mtw_prefix}{mtw_timedelta} to work today)"
 
     def _balance_readable(self, remaining_minutes: float) -> str:
-        """ Create a readable string explaining the balance, i.e. remaining minutes. """
+        """Create a readable string explaining the balance, i.e. remaining minutes."""
         remaining_timedelta: str = self._timedelta_str(abs(remaining_minutes))
         rm_postfix: str = "remaining" if remaining_minutes > 0 else "overtime"
         if remaining_minutes == 0:
@@ -1013,7 +1014,7 @@ class Work:
     # list #
 
     def list_entries(self, args) -> None:
-        """ List protocol entries. """
+        """List protocol entries."""
         selected_days: List[dt.date] = self.get_selected_period(args)
         self._list(
             days=selected_days,
@@ -1035,7 +1036,7 @@ class Work:
         filter_category: Optional[str] = None,
         filter_message: Optional[str] = None,
     ) -> None:
-        """ Print the given list of dates. For more than one date: Print a summary. """
+        """Print the given list of dates. For more than one date: Print a summary."""
 
         if not days:
             raise ValueError("At least one element is required")
@@ -1116,7 +1117,7 @@ class Work:
         filter_category: Optional[str],
         filter_message: Optional[str],
     ) -> List[Record]:
-        """ Filter the list of records based on category and message. """
+        """Filter the list of records based on category and message."""
         catfilter: str = filter_category or "*"
         msgfilter: str = filter_message or "*"
         filtered_records: List[Record] = []
@@ -1235,7 +1236,7 @@ class Work:
 
     @staticmethod
     def _none_found_msg(selected_days: List[dt.date]) -> str:
-        """ Create a message that no entry was found, matching the given day selection. """
+        """Create a message that no entry was found, matching the given day selection."""
         none_found_msg: str = "No records found"
         # Single day
         if len(selected_days) == 1:
@@ -1258,7 +1259,7 @@ class Work:
         return none_found_msg
 
     def _break_str(self, records: List[Record], i: int) -> Tuple[str, float]:
-        """ Create a break string for the given row. Skips last row. """
+        """Create a break string for the given row. Skips last row."""
         if i == len(records) - 1:
             return "", 0
 
@@ -1272,7 +1273,7 @@ class Work:
     # day #
 
     def day(self, args) -> None:
-        """ List the current day, including the active run. """
+        """List the current day, including the active run."""
         # pylint: disable=unused-argument
         self._list(
             [dt.date.today()],
@@ -1285,7 +1286,7 @@ class Work:
     # view #
 
     def view(self, args) -> None:
-        """ View protocol entries by attributes. """
+        """View protocol entries by attributes."""
 
         selected_days: List[dt.date] = self.get_selected_period(args)
         selected_records: List[Record] = list(
@@ -1327,7 +1328,7 @@ class Work:
     def view_by_category(
         self, records: List[Record], total_minutes_worked: float
     ) -> List[str]:
-        """ Create a view for the given protocol records by category. """
+        """Create a view for the given protocol records by category."""
 
         result: List[str] = []
         records_by_category: DefaultDict[str, List[Record]] = defaultdict(list)
@@ -1379,7 +1380,7 @@ class Work:
         return result
 
     def view_balance(self, period: List[dt.date], records: List[Record]) -> List[str]:
-        """ Create a view of the balance development over the given records. """
+        """Create a view of the balance development over the given records."""
 
         if not util.is_continuous_period(period):
             raise NotImplementedError("Expecting continuous period!")
@@ -1496,7 +1497,7 @@ class Work:
         return result
 
     class DateBuckets:
-        """ Grouping of `date`s in "buckets" – used in view balance. """
+        """Grouping of `date`s in "buckets" – used in view balance."""
 
         def __init__(self, period: List[dt.date]) -> None:
             if not util.is_continuous_period(period):
@@ -1509,7 +1510,7 @@ class Work:
             self._map_dates()
 
         def _set_name(self) -> None:
-            """ Based on the period, set name. """
+            """Based on the period, set name."""
             self.name = "month"
             if len(self._period) < 7 * 16:
                 self.name = "week"
@@ -1517,14 +1518,14 @@ class Work:
                 self.name = "day"
 
         def _map_dates(self) -> None:
-            """ Based on the selector, map the dates to buckets. """
+            """Based on the selector, map the dates to buckets."""
             self.mapped_dates = defaultdict(list)
             for day in self._period:
                 self.mapped_dates[self.to_selector(day)].append(day)
 
         @property
         def size(self) -> int:
-            """ Return the (maximum) length of each bucket in days. """
+            """Return the (maximum) length of each bucket in days."""
             return {
                 "day": 1,
                 "week": 7,
@@ -1532,7 +1533,7 @@ class Work:
             }[self.name]
 
         def to_selector(self, given_date: dt.date) -> str:
-            """ Transform given date to bucket selector. """
+            """Transform given date to bucket selector."""
             formatter: str = {
                 "day": "%Y-%m-%d",
                 "week": "%V-%Y",
@@ -1542,7 +1543,7 @@ class Work:
 
         @property
         def date_format(self) -> str:
-            """ Date format used, based on the bucket period. """
+            """Date format used, based on the bucket period."""
             date_format: str = "%d.%m."
             if (
                 self._period[0].year != self._period[-1].year
@@ -1603,7 +1604,7 @@ class Work:
     # export #
 
     def export(self, args) -> None:
-        """ Export any day or range of days as CSV. """
+        """Export any day or range of days as CSV."""
         selected_days: List[dt.date] = self.get_selected_period(args)
         writer = csv.writer(sys.stdout, lineterminator=os.linesep)
 
@@ -1619,7 +1620,7 @@ class Work:
     # edit + remove #
 
     def edit(self, args) -> None:
-        """ Edit protocol entries. Currently supports changing the time. """
+        """Edit protocol entries. Currently supports changing the time."""
 
         selection = self._start_manipulation_mode(args, "edit")
         if not selection:
@@ -1691,7 +1692,7 @@ class Work:
         self._end_manipulation_mode(num_edited=edited, verb="edited")
 
     def _new_time_or_not(self, time_name: str, old_val: dt.datetime) -> dt.datetime:
-        """ User interaction: Ask for a new time (or no change). """
+        """User interaction: Ask for a new time (or no change)."""
 
         user_choice = input(f"New {time_name} time? ({old_val.strftime(TIME_FORMAT)}) ")
         if user_choice == "":
@@ -1708,7 +1709,7 @@ class Work:
             return self._new_time_or_not(time_name, old_val)
 
     def _new_text_field_or_not(self, field_name: str, old_val: str) -> str:
-        """ User interaction: Ask for a new text field, field removal, or no change. """
+        """User interaction: Ask for a new text field, field removal, or no change."""
 
         user_choice: str = input(
             f'New {field_name} or remove ["-"]? ({old_val}) '
@@ -1722,7 +1723,7 @@ class Work:
         return user_choice
 
     def remove(self, args) -> None:
-        """ Remove protocol entries. """
+        """Remove protocol entries."""
 
         selection = self._start_manipulation_mode(args, "remove")
         if not selection:
@@ -1740,7 +1741,7 @@ class Work:
     def _start_manipulation_mode(
         self, args, verb: str
     ) -> Optional[Tuple[ProtocolMeta, List[Record]]]:
-        """ Common functionality for both manipulation modes. """
+        """Common functionality for both manipulation modes."""
 
         date: dt.date = self.get_selected_date(args)
         protocol: ProtocolMeta = self.dao.get_container(date=date)
@@ -1783,7 +1784,7 @@ class Work:
     def _get_index_selection(
         self, user_choice: str, valid_indices: List[int]
     ) -> Set[int]:
-        """ Match a user input to the chosen indices. Allows 1-many indices or "all". """
+        """Match a user input to the chosen indices. Allows 1-many indices or "all"."""
         if user_choice == "all":
             return set(valid_indices)
         try:
@@ -1797,7 +1798,7 @@ class Work:
         return selection
 
     def _end_manipulation_mode(self, num_edited: int, verb: str) -> None:
-        """ Print result message, update checksum. """
+        """Print result message, update checksum."""
 
         print(
             verb.capitalize() + f" {num_edited} record{'s' if num_edited != 1 else ''}"
@@ -1810,7 +1811,7 @@ class Work:
     # recess #
 
     def recess(self, args) -> None:
-        """ Manage recess days, a.k.a. vacation days or holidays (add, remove, list). """
+        """Manage recess days, a.k.a. vacation days or holidays (add, remove, list)."""
 
         action: Optional[Callable] = None
         output: str = ""
@@ -1859,7 +1860,7 @@ class Work:
         print(output)
 
     def _recess_add_vacation(self, vacation_period: List[str]) -> Tuple[Callable, str]:
-        """ Add a vacation for the given period. May be either one or two arguments. """
+        """Add a vacation for the given period. May be either one or two arguments."""
         first: dt.date
         last: dt.date
         action: Callable
@@ -1883,7 +1884,7 @@ class Work:
         )
 
     def _list_recess_days(self, year: int) -> None:
-        """ List recess days of the given year. """
+        """List recess days of the given year."""
         if not self.recess_dao.has_days(year=year):
             print(f"No free days stored for {year}.")
             return
@@ -1903,7 +1904,7 @@ class Work:
     # rehash #
 
     def rehash(self, args) -> None:
-        """ Recompute the info file checksum (after reconfirming). """
+        """Recompute the info file checksum (after reconfirming)."""
         # pylint: disable=unused-argument
 
         user_says: str = input(
@@ -1941,13 +1942,17 @@ class Work:
             return
 
         # Default: Print configuration path
-        print(f"Runtime configuration file path: {RC.path()}")
+        print(f"{RC.path()}")
 
     def _see(self, s_target) -> None:
-        """ See configuration details. """
+        """See configuration details."""
 
         if s_target == "dir":
-            print(f"Records directory: {self.dao.records_directory}")
+            print(
+                f"Records directory:   {self.dao.records_directory}\n"
+                f"Free days directory: {self.recess_dao.directory}\n"
+                f"Configuration file:  {RC.path()}"
+            )
         elif s_target == "expected hours":
             if self.configuration.expected_hours is None:
                 print("No expected hours configured.")
@@ -1971,7 +1976,7 @@ class Work:
 
     @staticmethod
     def _readable_d(date: dt.date) -> str:
-        """ Convert the given datetime.date to a human readable string with the day. """
+        """Convert the given datetime.date to a human readable string with the day."""
         if date == dt.date.today():
             return "today"
         elif date == (dt.date.today() + dt.timedelta(days=1)):
@@ -1983,23 +1988,23 @@ class Work:
 
     @staticmethod
     def _date_fmt(date_to_format: dt.date) -> str:
-        """ Return date format that only includes the year if it's not the current one. """
+        """Return date format that only includes the year if it's not the current one."""
         if date_to_format.year == dt.date.today().year:
             return "%d.%m."
         return "%d.%m.%Y"
 
     def _minutes_logged_on(self, requested_date: dt.date) -> float:
-        """ Return the minutes logged on the requested date. """
+        """Return the minutes logged on the requested date."""
         the_days_records: List[Record] = self.dao.get_entries(date=requested_date)
         return self._minutes_worked(the_days_records)
 
     @staticmethod
     def _minutes_worked(records: List[Record]) -> float:
-        """ Return the summed up work times contained in the given records. """
+        """Return the summed up work times contained in the given records."""
         return sum([r.get_minutes() for r in records])
 
     def _minutes_active_run(self) -> float:
-        """ Return the minutes the current run has been active. Raises if no run is active. """
+        """Return the minutes the current run has been active. Raises if no run is active."""
 
         active_start: Optional[dt.datetime] = self.dao.get_start_time()
         if active_start is None:
@@ -2048,7 +2053,7 @@ class Work:
 
     @staticmethod
     def _total_pauses(records: List[Record]) -> float:
-        """ Return the sum of all gaps between protocol entries. """
+        """Return the sum of all gaps between protocol entries."""
 
         if len(records) <= 1:
             return 0.0
@@ -2085,7 +2090,7 @@ class Work:
         return f"{hour_part} {minute_part}".strip()
 
     def _timedelta_str_signed(self, minutes: float) -> Tuple[str, str]:
-        """ Return a timedelta string and its sign. Allows negative values. """
+        """Return a timedelta string and its sign. Allows negative values."""
 
         sign: str = "+"
         if minutes < 0:
@@ -2094,7 +2099,7 @@ class Work:
         return timedelta_str, sign
 
     def _expected_minutes(self) -> List[float]:
-        """ Return a list of minutes to work on a regular week. """
+        """Return a list of minutes to work on a regular week."""
         normal_hours: List[float] = (
             list(self.configuration.expected_hours.values())
             if self.configuration.expected_hours
@@ -2104,7 +2109,7 @@ class Work:
         return [hour * 60.0 for hour in normal_hours]
 
     def _minutes_per_days(self, days: List[dt.date]) -> List[Tuple[dt.date, float]]:
-        """ Return a list of the minutes to work on the given days. """
+        """Return a list of the minutes to work on the given days."""
 
         # This method is the single place where expected hours are calculated.
         # That means that we only need to consider vacations or holidays here.
@@ -2123,14 +2128,14 @@ class Work:
         return result
 
     def _minutes_per_day(self, day: dt.date) -> float:
-        """ Return the minutes to work on the given day. """
+        """Return the minutes to work on the given day."""
 
         mins_per_days = self._minutes_per_days(days=[day])[0]
         _, minutes = mins_per_days
         return minutes
 
     def _minutes_to_work_today(self) -> float:
-        """ Calculate the remaining minutes to work today based on the current balance. """
+        """Calculate the remaining minutes to work today based on the current balance."""
         minutes_to_work: float = self._minutes_per_day(
             day=dt.date.today()
         ) + self._minute_balance_up_to(day=dt.date.today())
@@ -2172,7 +2177,7 @@ class Work:
     ### Convenience functions ###
 
     def _dt_now_stripped(self) -> dt.datetime:
-        """ Return the current time, with seconds and microseconds set to 0. """
+        """Return the current time, with seconds and microseconds set to 0."""
         return dt.datetime.now().replace(second=0, microsecond=0)
 
     @staticmethod
@@ -2200,7 +2205,7 @@ class Work:
 
     @staticmethod
     def _containing_month(day: dt.date) -> List[dt.date]:
-        """ Return the month that contains the given day. """
+        """Return the month that contains the given day."""
 
         first: dt.date = day.replace(day=1)
         # Get a day from the following month
