@@ -45,7 +45,7 @@ class RC:
     ### I/O ###
 
     def _dump(self, rc_file: IO) -> None:
-        """ Write this RC to file. """
+        """Write this RC to file."""
 
         # Convert data to JSON-formattable dict
         data: Dict = {
@@ -56,7 +56,7 @@ class RC:
         json.dump(data, rc_file, indent="\t")
 
     def _load(self, rc_file: IO) -> None:
-        """ Load an RC from file. """
+        """Load an RC from file."""
 
         data = json.load(rc_file)
         RC._ensure_dict_correctness(data)
@@ -67,21 +67,21 @@ class RC:
 
     @staticmethod
     def create_rc_file() -> None:
-        """ Create a RC file with default values. """
+        """Create a RC file with default values."""
 
         if os.path.lexists(RC_FILE_PATH):
             raise FileExistsError()
 
         # Create RC with default values
         rc: RC = RC._default_rc()
-        with open(RC_FILE_PATH, "w") as rc_file:
+        with open(RC_FILE_PATH, "w", encoding="utf-8") as rc_file:
             rc._dump(rc_file)
 
         print("RC file created at {}".format(RC_FILE_PATH))
 
     @staticmethod
     def example_rc_file() -> str:
-        """ Create the contents of an example RC file, setting all keys. """
+        """Create the contents of an example RC file, setting all keys."""
         rc: RC = RC._default_rc()
         with io.StringIO() as output:
             rc._dump(output)
@@ -90,32 +90,32 @@ class RC:
     @staticmethod
     def _default_rc():
         # type: () -> RC
-        """ Create an example RC object with mandatory values set. """
+        """Create an example RC object with mandatory values set."""
         rc = RC()
         rc.expected_hours = dict(zip(consts.WEEKDAYS, [8.0] * 5 + [0.0] * 2))
         return rc
 
     @staticmethod
     def load_rc():  # -> RC
-        """ Load a RC. If any RC file exists, retrieve it. If not, creates a basic file. """
+        """Load a RC. If any RC file exists, retrieve it. If not, creates a basic file."""
 
         if not os.path.lexists(RC_FILE_PATH):
             RC.create_rc_file()
             print("  Please check the file and update according to your needs.\n")
 
         rc = RC()
-        with open(RC_FILE_PATH, "r") as rc_file:
+        with open(RC_FILE_PATH, "r", encoding="utf-8") as rc_file:
             rc._load(rc_file)
         return rc
 
     @staticmethod
     def path() -> str:
-        """ Return the RC file path. """
+        """Return the RC file path."""
         return RC_FILE_PATH
 
     @staticmethod
     def _ensure_dict_correctness(data: Dict) -> None:
-        """ Ensure that the dict is fit for JSON (de)serialization. Raises if not. """
+        """Ensure that the dict is fit for JSON (de)serialization. Raises if not."""
 
         expected_keys: List[str] = [RC.expected_hours_k]
         for k in expected_keys:
@@ -126,7 +126,8 @@ class RC:
             if k not in expected_keys:
                 raise RCError(f'Unexpected key "{k}"')
 
-        pop_key = lambda l, k: l.pop(l.index(k))
+        def pop_key(list_, key):
+            return list_.pop(list_.index(key))
 
         # Verify expected_hours
         e_h = data[pop_key(expected_keys, RC.expected_hours_k)]
